@@ -188,9 +188,14 @@ class Tema(models.Model):
 
     headtags = models.TextField(db_column="tema_headtags")
     footags = models.TextField(db_column="tema_footags")
+
+    layout_parametros = JSONField(db_column='tema_layout_parametros', null=True, default=None)
+
     url_thumbnail = models.TextField(db_column="tema_url_thumbnail")
     url_screenshots = models.TextField(db_column="tema_url_screenshots")
     url_download = models.TextField(db_column="tema_url_download")
+    url_lojamodelo = models.TextField(db_column="tema_url_lojamodelo")
+
     data_criacao = models.DateTimeField(db_column="tema_data_criacao", default=0)
     data_modificacao = models.DateTimeField(db_column="tema_data_modificacao", auto_now=True)
 
